@@ -36,30 +36,30 @@
 #include <tqstringlist.h>
 #include <tqtimer.h>
 
-#include <kapplication.h>
-#include <kconfig.h>
+#include <tdeapplication.h>
+#include <tdeconfig.h>
 #include <kcursor.h>
 #include <kdebug.h>
-#include <kdeversion.h>
+#include <tdeversion.h>
 #ifdef KDE_USE_FINAL
 #undef Unsorted
 #endif
-#include <kfiledialog.h>
+#include <tdefiledialog.h>
 #include <kiconloader.h>
 #include <kimageeffect.h>
-#include <klocale.h>
-#include <kmessagebox.h>
+#include <tdelocale.h>
+#include <tdemessagebox.h>
 #include <kprinter.h>
 #include <kpropertiesdialog.h>
-#include <kstdaccel.h>
+#include <tdestdaccel.h>
 #include <kstdguiitem.h>
 #include <kstandarddirs.h>
-#include <kglobalsettings.h>
-#include <ktempfile.h>
-#include <kwin.h>
+#include <tdeglobalsettings.h>
+#include <tdetempfile.h>
+#include <twin.h>
 #include <netwm.h>
 #include <kurldrag.h>
-#include <kio/netaccess.h>
+#include <tdeio/netaccess.h>
 
 #include "filecache.h"
 #include "imagewindow.h"
@@ -95,7 +95,7 @@ ImageWindow::~ImageWindow()
 void ImageWindow::init()
 {
     setFocusPolicy( TQ_StrongFocus );
-    
+
     KCursor::setAutoHideCursor( this, true, true );
     KCursor::setHideCursorDelay( 1500 );
 
@@ -111,7 +111,7 @@ void ImageWindow::init()
     contrastMenu = 0L;
 
 
-    m_actions = new KActionCollection( this );
+    m_actions = new TDEActionCollection( this );
 
     if ( !s_handCursor ) {
         TQString file = locate( "appdata", "pics/handcursor.png" );
@@ -145,51 +145,51 @@ void ImageWindow::updateActions()
 
 void ImageWindow::setupActions()
 {
-    new KAction( i18n("Show Next Image"), KStdAccel::next(),
+    new TDEAction( i18n("Show Next Image"), TDEStdAccel::next(),
                  TQT_TQOBJECT(this), TQT_SLOT( slotRequestNext() ),
                  m_actions, "next_image" );
-    new KAction( i18n("Show Previous Image"), KStdAccel::prior(),
+    new TDEAction( i18n("Show Previous Image"), TDEStdAccel::prior(),
                  TQT_TQOBJECT(this), TQT_SLOT( slotRequestPrevious() ),
                  m_actions, "previous_image" );
 
-    new KAction( i18n("Delete Image"), SHIFT + Key_Delete,
+    new TDEAction( i18n("Delete Image"), SHIFT + Key_Delete,
                  TQT_TQOBJECT(this), TQT_SLOT( imageDelete() ),
                  m_actions, "delete_image" );
-    new KAction( i18n("Move Image to Trash"), Key_Delete,
+    new TDEAction( i18n("Move Image to Trash"), Key_Delete,
                  TQT_TQOBJECT(this), TQT_SLOT( imageTrash() ),
                  m_actions, "trash_image" );
 
-    new KAction( i18n("Zoom In"), Key_Plus,
+    new TDEAction( i18n("Zoom In"), Key_Plus,
                  TQT_TQOBJECT(this), TQT_SLOT( zoomIn() ),
                  m_actions, "zoom_in" );
-    new KAction( i18n("Zoom Out"), Key_Minus,
+    new TDEAction( i18n("Zoom Out"), Key_Minus,
                  TQT_TQOBJECT(this), TQT_SLOT( zoomOut() ),
                  m_actions, "zoom_out" );
-    new KAction( i18n("Restore Original Size"), Key_O,
+    new TDEAction( i18n("Restore Original Size"), Key_O,
                  TQT_TQOBJECT(this), TQT_SLOT( showImageOriginalSize() ),
                  m_actions, "original_size" );
-    new KAction( i18n("Maximize"), Key_M,
+    new TDEAction( i18n("Maximize"), Key_M,
                  TQT_TQOBJECT(this), TQT_SLOT( maximize() ),
                  m_actions, "maximize" );
 
-    new KAction( i18n("Rotate 90 Degrees"), Key_9,
+    new TDEAction( i18n("Rotate 90 Degrees"), Key_9,
                  TQT_TQOBJECT(this), TQT_SLOT( rotate90() ),
                  m_actions, "rotate90" );
-    new KAction( i18n("Rotate 180 Degrees"), Key_8,
+    new TDEAction( i18n("Rotate 180 Degrees"), Key_8,
                  TQT_TQOBJECT(this), TQT_SLOT( rotate180() ),
                  m_actions, "rotate180" );
-    new KAction( i18n("Rotate 270 Degrees"), Key_7,
+    new TDEAction( i18n("Rotate 270 Degrees"), Key_7,
                  TQT_TQOBJECT(this), TQT_SLOT( rotate270() ),
                  m_actions, "rotate270" );
 
-    new KAction( i18n("Flip Horizontally"), Key_Asterisk,
+    new TDEAction( i18n("Flip Horizontally"), Key_Asterisk,
                  TQT_TQOBJECT(this), TQT_SLOT( flipHoriz() ),
                  m_actions, "flip_horicontally" );
-    new KAction( i18n("Flip Vertically"), Key_Slash,
+    new TDEAction( i18n("Flip Vertically"), Key_Slash,
                  TQT_TQOBJECT(this), TQT_SLOT( flipVert() ),
                  m_actions, "flip_vertically" );
 
-    new KAction( i18n("Print Image..."), KStdAccel::print(),
+    new TDEAction( i18n("Print Image..."), TDEStdAccel::print(),
                  TQT_TQOBJECT(this), TQT_SLOT( printImage() ),
                  m_actions, "print_image" );
     KStdAction::saveAs( TQT_TQOBJECT(this), TQT_SLOT( saveImage() ),
@@ -198,64 +198,64 @@ void ImageWindow::setupActions()
     KStdAction::close( TQT_TQOBJECT(this), TQT_SLOT( close() ),
                  m_actions, "close_image" );
     // --------
-    new KAction( i18n("More Brightness"), Key_B,
+    new TDEAction( i18n("More Brightness"), Key_B,
                  TQT_TQOBJECT(this), TQT_SLOT( moreBrightness() ),
                  m_actions, "more_brightness" );
-    new KAction( i18n("Less Brightness"), SHIFT + Key_B,
+    new TDEAction( i18n("Less Brightness"), SHIFT + Key_B,
                  TQT_TQOBJECT(this), TQT_SLOT( lessBrightness() ),
                  m_actions, "less_brightness" );
-    new KAction( i18n("More Contrast"), Key_C,
+    new TDEAction( i18n("More Contrast"), Key_C,
                  TQT_TQOBJECT(this), TQT_SLOT( moreContrast() ),
                  m_actions, "more_contrast" );
-    new KAction( i18n("Less Contrast"), SHIFT + Key_C,
+    new TDEAction( i18n("Less Contrast"), SHIFT + Key_C,
                  TQT_TQOBJECT(this), TQT_SLOT( lessContrast() ),
                  m_actions, "less_contrast" );
-    new KAction( i18n("More Gamma"), Key_G,
+    new TDEAction( i18n("More Gamma"), Key_G,
                  TQT_TQOBJECT(this), TQT_SLOT( moreGamma() ),
                  m_actions, "more_gamma" );
-    new KAction( i18n("Less Gamma"), SHIFT + Key_G,
+    new TDEAction( i18n("Less Gamma"), SHIFT + Key_G,
                  TQT_TQOBJECT(this), TQT_SLOT( lessGamma() ),
                  m_actions, "less_gamma" );
 
     // --------
-    new KAction( i18n("Scroll Up"), Key_Up,
+    new TDEAction( i18n("Scroll Up"), Key_Up,
                  TQT_TQOBJECT(this), TQT_SLOT( scrollUp() ),
                  m_actions, "scroll_up" );
-    new KAction( i18n("Scroll Down"), Key_Down,
+    new TDEAction( i18n("Scroll Down"), Key_Down,
                  TQT_TQOBJECT(this), TQT_SLOT( scrollDown() ),
                  m_actions, "scroll_down" );
-    new KAction( i18n("Scroll Left"), Key_Left,
+    new TDEAction( i18n("Scroll Left"), Key_Left,
                  TQT_TQOBJECT(this), TQT_SLOT( scrollLeft() ),
                  m_actions, "scroll_left" );
-    new KAction( i18n("Scroll Right"), Key_Right,
+    new TDEAction( i18n("Scroll Right"), Key_Right,
                  TQT_TQOBJECT(this), TQT_SLOT( scrollRight() ),
                  m_actions, "scroll_right" );
     // --------
-    new KAction( i18n("Pause Slideshow"), Key_P,
+    new TDEAction( i18n("Pause Slideshow"), Key_P,
                  TQT_TQOBJECT(this), TQT_SLOT( pauseSlideShow() ),
                  m_actions, "kuick_slideshow_pause" );
 
-    KAction *fullscreenAction = KStdAction::fullScreen(TQT_TQOBJECT(this), TQT_SLOT( toggleFullscreen() ), m_actions, 0 );
+    TDEAction *fullscreenAction = KStdAction::fullScreen(TQT_TQOBJECT(this), TQT_SLOT( toggleFullscreen() ), m_actions, 0 );
 
-    KAction *reloadAction = new KAction( i18n("Reload Image"), KStdAccel::shortcut(KStdAccel::Reload),
+    TDEAction *reloadAction = new TDEAction( i18n("Reload Image"), TDEStdAccel::shortcut(TDEStdAccel::Reload),
                                          TQT_TQOBJECT(this), TQT_SLOT( reload() ),
                                          m_actions, "reload_image" );
 
-    new KAction( i18n("Properties"), ALT + Key_Return,
+    new TDEAction( i18n("Properties"), ALT + Key_Return,
                  TQT_TQOBJECT(this), TQT_SLOT( slotProperties() ),
                  m_actions, "properties" );
 
     m_actions->readShortcutSettings();
 
-    // Unfortunately there is no KAction::setShortcutDefault() :-/
+    // Unfortunately there is no TDEAction::setShortcutDefault() :-/
     // so add Key_Return as fullscreen shortcut _after_ readShortcutSettings()
     addAlternativeShortcut(fullscreenAction, Key_Return);
     addAlternativeShortcut(reloadAction, Key_Enter);
 }
 
-void ImageWindow::addAlternativeShortcut(KAction *action, int key)
+void ImageWindow::addAlternativeShortcut(TDEAction *action, int key)
 {
-    KShortcut cut( action->shortcut() );
+    TDEShortcut cut( action->shortcut() );
     if (cut == action->shortcutDefault()) {
         cut.append(KKey(key));
         action->setShortcut(cut);
@@ -288,7 +288,7 @@ void ImageWindow::setFullscreen( bool enable )
 
 void ImageWindow::updateGeometry( int imWidth, int imHeight )
 {
-//     qDebug("::updateGeometry: %i, %i", imWidth, imHeight);
+//     tqDebug("::updateGeometry: %i, %i", imWidth, imHeight);
     //  XMoveWindow( x11Display(), win, 0, 0 );
     XResizeWindow( x11Display(), win, imWidth, imHeight );
 
@@ -307,7 +307,7 @@ void ImageWindow::updateGeometry( int imWidth, int imHeight )
     }
 
     updateCursor();
-	
+
     TQString caption = i18n( "Filename (Imagewidth x Imageheight)",
                             "%3 (%1 x %2)" );
     caption = caption.arg( m_kuim->originalWidth() ).
@@ -321,7 +321,7 @@ void ImageWindow::centerImage()
     int w, h;
     if ( myIsFullscreen )
     {
-        TQRect desktopRect = KGlobalSettings::desktopGeometry( this );
+        TQRect desktopRect = TDEGlobalSettings::desktopGeometry( this );
         w = desktopRect.width();
         h = desktopRect.height();
     }
@@ -439,7 +439,7 @@ bool ImageWindow::showNextImage( KuickFile *file )
 	// updateWidget( true ); // already called from loadImage()
 	if ( !isVisible() )
 		showWindow();
-		
+
 	showImage();
 	return true;
     }
@@ -592,10 +592,10 @@ void ImageWindow::keyPressEvent( TQKeyEvent *e )
 
     if ( key == Key_Shift )
         updateCursor( ZoomCursor );
-	
-    if ( key == Key_Escape || KStdAccel::close().contains( KKey( e ) ) )
+
+    if ( key == Key_Escape || TDEStdAccel::close().contains( KKey( e ) ) )
         close( true );
-    else if ( KStdAccel::save().contains( KKey( e ) ) )
+    else if ( TDEStdAccel::save().contains( KKey( e ) ) )
         saveImage();
 
     else {
@@ -664,7 +664,7 @@ void ImageWindow::updateCursor( KuickCursor cursor )
         default:
             if ( isCursorHidden() )
                 return;
-            
+
             if ( imageWidth() > width() || imageHeight() > height() )
                 setCursor( *s_handCursor );
             else
@@ -680,7 +680,7 @@ void ImageWindow::mouseMoveEvent( TQMouseEvent *e )
     }
 
     if ( e->state() & ShiftButton ) {
-	
+
 	if ( !transWidget ) {
 	    transWidget = new TQWidget( this );
 	    transWidget->setGeometry( 0, 0, width(), height() );
@@ -693,10 +693,10 @@ void ImageWindow::mouseMoveEvent( TQMouseEvent *e )
  	p.eraseRect( transWidget->rect() );
 	transWidget->show();
 	tqApp->processOneEvent();
-	
+
 	int width  = e->x() - xposPress;
 	int height = e->y() - yposPress;
-	
+
 	if ( width < 0 ) {
 	    width = abs( width );
 	    xzoom = e->x();
@@ -759,7 +759,7 @@ void ImageWindow::mouseReleaseEvent( TQMouseEvent *e )
     }
 
     if ( yposPress > y ) {
-	topY = y;	
+	topY = y;
 	botY = yposPress;
     }
     else {
@@ -839,10 +839,10 @@ void ImageWindow::dropEvent( TQDropEvent *e )
     if ( KURLDrag::decode( e, list ) && !list.isEmpty()) {
         TQString tmpFile;
         const KURL &url = list.first();
-        if (KIO::NetAccess::download( url, tmpFile, this ) )
+        if (TDEIO::NetAccess::download( url, tmpFile, this ) )
         {
 	    loadImage( tmpFile );
-	    KIO::NetAccess::removeTempFile( tmpFile );
+	    TDEIO::NetAccess::removeTempFile( tmpFile );
 	}
 	updateWidget();
 	e->accept();
@@ -925,7 +925,7 @@ void ImageWindow::saveImage()
     TQCheckBox *keepSize = new TQCheckBox( i18n("Keep original image size"), 0L);
     keepSize->setChecked( true );
     KFileDialog dlg( m_saveDirectory, tmp.fileFilter, this, "filedialog", true
-#if KDE_VERSION >= 310
+#if TDE_VERSION >= 310
                      ,keepSize
 #endif
                    );
@@ -962,7 +962,7 @@ void ImageWindow::saveImage()
     if ( lastDir != m_saveDirectory )
         m_saveDirectory = lastDir;
 
-#if KDE_VERSION < 310
+#if TDE_VERSION < 310
     delete keepSize;
 #endif
 }
@@ -981,34 +981,34 @@ bool ImageWindow::saveImage( const KURL& dest, bool keepOriginalSize )
 	TQString saveFile;
 	if ( dest.isLocalFile() )
 		saveFile = dest.path();
-	else 
+	else
 	{
 		TQString extension = TQFileInfo( dest.fileName() ).extension();
 		if ( !extension.isEmpty() )
 			extension.prepend( '.' );
-		
+
 		KTempFile tmpFile( TQString(), extension );
 		if ( tmpFile.status() != 0 )
 			return false;
 		tmpFile.close();
 		if ( tmpFile.status() != 0 )
 			return false;
-		saveFile = tmpFile.name();		
+		saveFile = tmpFile.name();
 	}
-	
-    if ( saveIm ) 
+
+    if ( saveIm )
     {
         Imlib_apply_modifiers_to_rgb( id, saveIm );
         success = Imlib_save_image( id, saveIm,
                                     TQFile::encodeName( saveFile ).data(),
                                     NULL );
-        if ( success && !dest.isLocalFile() ) 
+        if ( success && !dest.isLocalFile() )
         {
         	if ( isFullscreen() )
         		toggleFullscreen(); // otherwise upload window would block us invisibly
-        	success = KIO::NetAccess::upload( saveFile, dest, const_cast<ImageWindow*>( this ) );
+        	success = TDEIO::NetAccess::upload( saveFile, dest, const_cast<ImageWindow*>( this ) );
         }
-                                    
+
         Imlib_kill_image( id, saveIm );
     }
 
@@ -1128,7 +1128,7 @@ int ImageWindow::desktopWidth( bool totalScreen ) const
 {
     if ( myIsFullscreen || totalScreen )
     {
-        return KGlobalSettings::desktopGeometry(topLevelWidget()).width();
+        return TDEGlobalSettings::desktopGeometry(topLevelWidget()).width();
     } else
 	return Kuick::workArea().width();
 }
@@ -1137,7 +1137,7 @@ int ImageWindow::desktopWidth( bool totalScreen ) const
 int ImageWindow::desktopHeight( bool totalScreen ) const
 {
     if ( myIsFullscreen || totalScreen ) {
-        return KGlobalSettings::desktopGeometry(topLevelWidget()).height();
+        return TDEGlobalSettings::desktopGeometry(topLevelWidget()).height();
     } else {
 	return Kuick::workArea().height();
     }
@@ -1146,7 +1146,7 @@ int ImageWindow::desktopHeight( bool totalScreen ) const
 TQSize ImageWindow::maxImageSize() const
 {
     if ( myIsFullscreen ) {
-        return KGlobalSettings::desktopGeometry(topLevelWidget()).size();
+        return TDEGlobalSettings::desktopGeometry(topLevelWidget()).size();
     }
     else {
 	return Kuick::workArea().size() - Kuick::frameSize( winId() );
@@ -1192,12 +1192,12 @@ bool ImageWindow::canZoomTo( int newWidth, int newHeight )
 {
     if ( !ImlibWidget::canZoomTo( newWidth, newHeight ) )
         return false;
-    
-    TQSize desktopSize = KGlobalSettings::desktopGeometry(topLevelWidget()).size();
+
+    TQSize desktopSize = TDEGlobalSettings::desktopGeometry(topLevelWidget()).size();
 
     int desktopArea = desktopSize.width() * desktopSize.height();
     int imageArea = newWidth * newHeight;
-    
+
     if ( imageArea > desktopArea * kdata->maxZoomFactor )
     {
         return KMessageBox::warningContinueCancel(
@@ -1209,7 +1209,7 @@ bool ImageWindow::canZoomTo( int newWidth, int newHeight )
             "ImageWindow_confirm_very_large_window"
             ) == KMessageBox::Continue;
     }
-    
+
     return true;
 }
 
@@ -1219,7 +1219,7 @@ void ImageWindow::rotated( KuickImage *kuim, int rotation )
         return;
 
     ImlibWidget::rotated( kuim, rotation );
-    
+
     if ( rotation == ROT_90 || rotation == ROT_270 )
         autoScale( kuim ); // ### BUG: only autoScale when configured!
 }
@@ -1247,5 +1247,5 @@ bool ImageWindow::isCursorHidden() const
 {
     return cursor().shape() == TQt::BlankCursor;
 }
-    
+
 #include "imagewindow.moc"
